import os
import http.server

from functools import partial
from grapher import web

PORT = 4200
HOSTNAME = ''

Handler = partial(
    http.server.SimpleHTTPRequestHandler,
    directory=os.path.join(*web.__path__, 'ui'))

with http.server.HTTPServer((HOSTNAME, PORT), Handler) as httpd:
    print('Warning! This is not production server. Use it only for local testing.')
    print('Listening on http://0.0.0.0:4200')
    httpd.serve_forever()



from setuptools import setup


setup(
    name='grapher-web',
    version='1.1.2',
    license='Apache Software License',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: Apache Software License',
        'Topic :: System :: Monitoring',
        'Topic :: System :: Systems Administration',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    keywords=['data', 'visualization', 'monitoring', 'graphs'],
    python_requires='~=3.7',
    description='Grapher Web UI',
    author='Volodymyr Paslavskyy',
    author_email='qfoxic@gmail.com',
    packages=['grapher.web'],
    include_package_data=True,
    url='https://gitlab.com/grapher/grapher-web/',
    download_url='https://gitlab.com/grapher/grapher-web/-/archive/1.1.2/grapher-web-1.1.2.tar.gz'
)
